/**
 * Copyright 2010 Västra Götalandsregionen
 *
 *   This library is free software; you can redistribute it and/or modify
 *   it under the terms of version 2.1 of the GNU Lesser General Public
 *   License as published by the Free Software Foundation.
 *
 *   This library is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU Lesser General Public License for more details.
 *
 *   You should have received a copy of the GNU Lesser General Public
 *   License along with this library; if not, write to the
 *   Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 *   Boston, MA 02111-1307  USA
 */

package se.vgregion.portal.cs.domain.persistence.jpa;

import org.springframework.stereotype.Repository;
import se.vgregion.dao.domain.patterns.repository.db.jpa.DefaultJpaRepository;
import se.vgregion.portal.cs.domain.SiteKey;
import se.vgregion.portal.cs.domain.persistence.SiteKeyRepository;

import javax.persistence.NoResultException;
import javax.persistence.Query;

/**
 * Jpa implementation of SiteKey Repository.
 *
 * @author <a href="mailto:david.rosell@redpill-linpro.com">David Rosell</a>
 */
@Repository
public class JpaSiteKeyRepository extends DefaultJpaRepository<SiteKey, Long> implements SiteKeyRepository {

    @Override
    public void save(SiteKey siteKey) {
        if (siteKey.getId() == null) {
            entityManager.persist(siteKey);
        } else {
            entityManager.merge(siteKey);
        }
    }

    @Override
    public SiteKey findBySiteKey(String siteKey) {
        String queryString = "SELECT s FROM SiteKey s WHERE s.siteKey = :siteKey";
        Query query = entityManager.createQuery(queryString).setParameter("siteKey", siteKey);

        try {
            SiteKey singleResult = (SiteKey) query.getSingleResult();
            return singleResult;
        } catch (NoResultException ex) {
            //ok, return null
            return null;
        }
    }
}
